#region Copyright Syncfusion Inc. 2001 - 2015
// Copyright Syncfusion Inc. 2001 - 2015. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
#endregion
using Syncfusion.SfChart.XForms;
using System;
using System.Collections.ObjectModel;
using System.Globalization;
using System.Threading.Tasks;
using Xamarin.Forms;

namespace ChartSample
{
    public class AutoScrolling : ContentPage
    {
        private Random random;

        private readonly ObservableCollection<ChartDataPoint> data = new ObservableCollection<ChartDataPoint>();

        private int count;

        private SfChart chart;

        public AutoScrolling()
        {
            Title = "Auto Scrolling";
            var label = new Label
            {
                HorizontalOptions = LayoutOptions.Start,
                Text = " In this demo, a data point is being added every 500 milliseconds." +
                       " The Chart is then automatically scrolled to display the fixed range of data points at the end." +
                       " You can also pan to view previous data points. In this sample the delta value is 5 seconds.",
            };

			if (Device.OS == TargetPlatform.iOS) {
				label.FontSize = 12;
				label.XAlign = TextAlignment.Center;
				label.YAlign = TextAlignment.Center;
			}

            Content = new StackLayout
            {
                Padding = Device.OnPlatform(new Thickness(5, 10, 5, 10), new Thickness(5, 10, 5, 10), new Thickness(15, 10, 15, 10)),
                Children = { GetChart(), label }
            };
        }

        private SfChart GetChart()
        {
            random = new Random();
            
            LoadData();

            chart = new SfChart
            {
                PrimaryAxis = new DateTimeAxis() {AutoScrollingDelta = 5, AutoScrollingDeltaType = DateTimeDeltaType.Seconds },
                VerticalOptions = LayoutOptions.FillAndExpand
            };
            chart.PrimaryAxis.LabelStyle.LabelFormat = "HH:mm:ss";

            var axis = new NumericalAxis
            {
                Minimum = 0,
                Maximum = 100,
                LabelStyle = {LabelsPosition = AxisElementPosition.Outside},
                TickPosition = AxisElementPosition.Outside
            };
            chart.SecondaryAxis = axis;

            var lineSeries = new ColumnSeries {ItemsSource = data};

            chart.Series.Add(lineSeries);
            
            chart.ChartBehaviors.Add(new ChartZoomPanBehavior {EnablePanning = true, EnableZooming = false,});
            
            UpdateData();
            
            return chart;
        }

        DateTime time = DateTime.Now;

        private void LoadData()
        {
            for (var i = 0; i < 2; i++)
            {
                data.Add(new ChartDataPoint(time, random.Next(0, 100)));
                time = time.AddMilliseconds(500);
                count++;
            }
            count = data.Count;
        }

        private async void UpdateData()
        {
            while (true)
            {
                await Task.Delay(500);
                data.Add(new ChartDataPoint(time, random.Next(0, 100)));
                time = time.AddMilliseconds(500);
                count++;
            }
        }
    }
}