#region Copyright Syncfusion Inc. 2001 - 2015
// Copyright Syncfusion Inc. 2001 - 2015. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
#endregion

using System.Linq;
using Syncfusion.SfChart.XForms;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Reflection;
using Xamarin.Forms;

namespace ChartSample
{
    public class MainPage : ContentPage
    {
        public MainPage()
        {
            Title = "  Essential Chart";
            var items = new List<Item>
            {
                new Item {Name = "Column", ItemType = typeof (Column)},
                new Item {Name = "Line", ItemType = typeof (Line)},
                new Item {Name = "Bubble", ItemType = typeof (Bubble)},
                new Item {Name = "Spline", ItemType = typeof (Spline)},
                new Item {Name = "Pie", ItemType = typeof (Pie)},
                new Item {Name = "Doughnut", ItemType = typeof (Doughnut)},
                new Item {Name = "Stacked Column", ItemType = typeof (StackingColumn)},
                new Item {Name = "100% Stacked Column", ItemType = typeof (StackingColumn100)},
                new Item {Name = "Bar", ItemType = typeof (Bar)},
                new Item {Name = "Stacked Bar", ItemType = typeof (StackingBar)},
                new Item {Name = "100% Stacked Bar", ItemType = typeof (StackingBar100)},
                new Item {Name = "Area", ItemType = typeof (Area)},
                new Item {Name = "Stacked Area", ItemType = typeof (StackingArea)},
                new Item {Name = "100% Stacked Area", ItemType = typeof (StackingArea100)},
                new Item {Name = "Candle", ItemType = typeof (Candle)},
                new Item {Name = "OHLC", ItemType = typeof (OHLC)},
                new Item {Name = "Live Update", ItemType = typeof (LiveUpdate)},
                new Item {Name = "Multiple Charts", ItemType = typeof (MultipleSeries)},
                new Item {Name = "Data Point Selection", ItemType = typeof (DataPointSelection)},
                new Item {Name = "Zooming and Panning", ItemType = typeof (ZoomingAndPanning)},
                new Item {Name = "Category Axis", ItemType = typeof (Category)},
                new Item {Name = "Numerical Axis", ItemType = typeof (Numerical)},
                new Item {Name = "DateTime Axis", ItemType = typeof (Date)},
                new Item {Name = "Multiple Axes", ItemType = typeof (MultipleAxis)},
                new Item {Name = "Auto Scrolling", ItemType = typeof (AutoScrolling)}
            };

            var listview = new ListView
            {
                ItemsSource = items,
            };

            listview.ItemSelected += listview_ItemSelected;
            listview.ItemTemplate = new DataTemplate(typeof (TextCell));
            listview.ItemTemplate.SetBinding(TextCell.TextProperty, "Name");
            listview.HeightRequest = 100;

            Content = listview;
        }

        private async void listview_ItemSelected(object sender, SelectedItemChangedEventArgs e)
        {
            var item = e.SelectedItem as Item;

            if (item == null) return;
            var constructors =
                item.ItemType.GetTypeInfo().DeclaredConstructors;

            foreach (
                var page in
                    from constructor in constructors
                    where constructor.GetParameters().Length == 0
                    select (Page) constructor.Invoke(null))
            {
                await Navigation.PushAsync(page);
                break;
            }

            //This is for reset the selected item
            ((ListView) sender).SelectedItem = null;
        }

        public static ObservableCollection<Model> GetAreaData()
        {
            var datas = new ObservableCollection<Model>
            {
//                new Model1("2010", 45),
//                new Model1("2011", 56),
//                new Model("2012", 23),
//                new Model1("2013", 43),
//                new Model1("2014", Double.NaN),
//                new Model1("2015", 54),
//                new Model1("2016", 43),
//                new Model1("2017", 23),
//                new Model1("2018", 34)
            };
            return datas;
        }

        public static ObservableCollection<ChartDataPoint> GetData1()
        {
            var datas = new ObservableCollection<ChartDataPoint>
            {
                new ChartDataPoint("2010", 45),
                new ChartDataPoint("2011", 89),
                new ChartDataPoint("2012", 23),
                new ChartDataPoint("2013", 43),
				new ChartDataPoint("2015", 54)
            };
            return datas;
        }

		public static ObservableCollection<ChartDataPoint> GetLineData()
		{
			double value = 100;
			Random randomNumber = new Random ();
			var datas = new ObservableCollection<ChartDataPoint> ();

				for (int i = 0; i < 1000; i++)
				{
				datas.Add(new ChartDataPoint(i, value));
					if (randomNumber.NextDouble() > .5)
					{
						value += randomNumber.NextDouble();
					}
					else
					{
						value -= randomNumber.NextDouble();
					}
				};

			
			return datas;
		}

        public static ObservableCollection<ChartDataPoint> GetBubbleData()
        {
            var datas = new ObservableCollection<ChartDataPoint>
            {
                new ChartDataPoint("Jan", 45, 10),
                new ChartDataPoint("Feb", 86, 12),
                new ChartDataPoint("Mar", 23, 22),
                new ChartDataPoint("Apr", 43, 35),
                new ChartDataPoint("May", 64, 20),
				new ChartDataPoint("Jun", 40, 30)
            };
            return datas;
        }

        public static ObservableCollection<ChartDataPoint> GetCategoryData()
        {
            var datas = new ObservableCollection<ChartDataPoint>
            {
                new ChartDataPoint("Bentley", 54),
                new ChartDataPoint("Audi", 24),
                new ChartDataPoint("BMW", 53),
                new ChartDataPoint("Jaguar", 63),
                new ChartDataPoint("Skoda", 35)
            };
            return datas;
        }

        public static ObservableCollection<ChartDataPoint> GetNumericalData()
        {
            var datas = new ObservableCollection<ChartDataPoint>
            {
                new ChartDataPoint(1, 54),
                new ChartDataPoint(2, 24),
                new ChartDataPoint(3, 53),
                new ChartDataPoint(4, 63),
                new ChartDataPoint(5, 35)
            };
            return datas;
        }

        public static ObservableCollection<ChartDataPoint> GetData2()
        {
            var datas = new ObservableCollection<ChartDataPoint>
            {
                new ChartDataPoint("2010", 54),
                new ChartDataPoint("2011", 24),
                new ChartDataPoint("2012", 53),
                new ChartDataPoint("2013", 63),
                new ChartDataPoint("2014", 35)
            };
            return datas;
        }

        public static ObservableCollection<ChartDataPoint> GetData3()
        {
            var datas = new ObservableCollection<ChartDataPoint>
            {
                new ChartDataPoint("2010", 14),
                new ChartDataPoint("2011", 54),
                new ChartDataPoint("2012", 23),
                new ChartDataPoint("2013", 53),
                new ChartDataPoint("2014", 25)
            };
            return datas;
        }

        public static ObservableCollection<ChartDataPoint> GetFinancialData()
        {
            var datas = new ObservableCollection<ChartDataPoint>
            {
                new ChartDataPoint("2010", 873.8, 878.85, 855.5, 860.5),
                new ChartDataPoint("2011", 861, 868.4, 835.2, 843.45),
                new ChartDataPoint("2012", 846.15, 853, 838.5, 847.5),
                new ChartDataPoint("2013", 846, 860.75, 841, 855),
                new ChartDataPoint("2014", 841, 845, 827.85, 838.65)
            };
            return datas;
        }

        public static ObservableCollection<ChartDataPoint> GetDateTimValue()
        {
            var datas = new ObservableCollection<ChartDataPoint>
            {
                new ChartDataPoint(new DateTime(2012, 01, 1), 14),
                new ChartDataPoint(new DateTime(2012, 01, 2), 54),
                new ChartDataPoint(new DateTime(2012, 01, 3), 23),
                new ChartDataPoint(new DateTime(2012, 01, 4), 53),
                new ChartDataPoint(new DateTime(2012, 01, 5), 25)
            };
            return datas;
        }

        public static ObservableCollection<ChartDataPoint> GetSelectionData()
        {
            var datas = new ObservableCollection<ChartDataPoint>
            {
                new ChartDataPoint("Jan", 42),
                new ChartDataPoint("Feb", 44),
                new ChartDataPoint("Mar", 53),
                new ChartDataPoint("Apr", 64),
                new ChartDataPoint("May", 75),
                new ChartDataPoint("Jun", 83)
            };
            return datas;
        }
    }

    public class Item
    {
        public string Name { get; set; }
        public Type ItemType { get; set; }
        public Command ItemCommand { get; set; }
    }

    public class Model1
    {
        public string Name { get; set; }

        public double Value { get; set; }

        public Model1(string name, double value)
        {
            Name = name;
            Value = value;
        }
    }
}