#region Copyright Syncfusion Inc. 2001 - 2015
// Copyright Syncfusion Inc. 2001 - 2015. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
#endregion
using Syncfusion.SfChart.XForms;
using System.Collections.Generic;
using Xamarin.Forms;

namespace ChartSample
{
    public class DataPointSelection : ContentPage
    {
        private readonly Label label;

        public DataPointSelection()
        {
            Title = "Data Point Selection";

            label = new Label {FontSize = 20, HorizontalOptions = LayoutOptions.Center};

            Grid grid = new Grid
            {
				Padding = new Thickness {Bottom = 10, Top=15,  Left = 5},
                VerticalOptions = LayoutOptions.FillAndExpand,
                RowDefinitions = 
                {
                    new RowDefinition { Height = new GridLength(1, GridUnitType.Star) },
                    new RowDefinition { Height =  GridLength.Auto  }
                },
            };

            var chart = GetChart();
            grid.Children.Add(chart);
            Grid.SetRow(chart, 0);
            grid.Children.Add(label);
            Grid.SetRow(label, 1);
            Content = grid;
        }

        private SfChart GetChart()
        {
            var chart = new SfChart
            {
                VerticalOptions = LayoutOptions.FillAndExpand,

                PrimaryAxis =
                    new CategoryAxis
                    {
                        LabelPlacement = LabelPlacement.BetweenTicks,
                        Title = new ChartAxisTitle {Text = "Month"}
                    },
                SecondaryAxis =
                    new NumericalAxis
                    {
                        Title = new ChartAxisTitle {Text = "Sales"},
                        LabelStyle = {LabelFormat = "$##.##"}
                    },
            };

            chart.Series.Add(new ColumnSeries
            {
                DataMarker = new ChartDataMarker(),
                ItemsSource = MainPage.GetSelectionData(),
                DataMarkerPosition = DataMarkerPosition.Center,
                SelectedDataPointIndex = 2,
                EnableDataPointSelection = true,
            });

            chart.ChartBehaviors.Add(new ChartSelectionBehavior());
            chart.SelectionChanged += chart_SelectionChanged;
            return chart;
        }

        private void chart_SelectionChanged(object sender, ChartSelectionEventArgs e)
        {
            var selectedindex = e.SelectedDataPointIndex;
            if (selectedindex < 0)
            {
                label.Text = "Tap on a bar segment to select a data point";
                label.FontSize = 15;
                return;
            }
            label.FontSize = 20;
            var series = e.SelectedSeries;
            if (series == null) return;
            var datapoints = (series.ItemsSource as IList<ChartDataPoint>);

            if (datapoints == null) return;
            var x = datapoints[selectedindex].XValue.ToString();
            var y = datapoints[selectedindex].YValue.ToString();
            label.Text = "Month : " + x + ",  Sales : $" + y;
        }
    }
}